==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/Tool/GetUriTitle.pm <==
#
# WiKicker
#
#  GetUriTitle.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GetUriTitle.pm,v 1.5 2004/01/29 14:37:01 naney Exp $
#
#

package WiKicker::Tool::GetUriTitle;

use strict;

use HTML::Parser;
use LWP::UserAgent;
use WiKicker::UTF8;

# my $tool = WiKicker::Tool::GetUriTitle->new;
# $tool->get_bracketed_title('http://www.google.com');

sub new {
  my $class = shift;

  return bless {}, $class;
}

sub start_handler {
  my ($self, $tagname) = @_;
  if ($tagname eq 'title') {
    $self->handler(text => sub { $self->{title} .= shift }, "dtext");
    $self->handler(end  => sub { shift->eof if shift eq "title"; }, "tagname,self");
  }
  elsif ($tagname eq 'h1') {
    $self->handler(text => sub { $self->{h1} .= shift }, "dtext");
    $self->handler(end => sub { shift->eof if shift eq "h1"; }, "tagname, self");
  }
}

sub get_content {
  my ($self, $url) = @_;

  my $agent = LWP::UserAgent->new;
  my $response = $agent->request(HTTP::Request->new('GET', $url));
  unless ($response->is_success) {
    return '';
  }

  my $content_type = $response->content_type;
  if ($content_type && $content_type ne 'text/html') {
    return '';
  }
  unless ($content_type) {
    unless ($url =~ /\.html?$/) {
      return '';
    }
  }

  return $response->content;
}

sub get_title_from_html {
  my ($self, $html) = @_;

  my $p = HTML::Parser->new(api_version => 3);
  $p->handler(start => \&start_handler, "self,tagname");
  $p->parse($html);
  my $title = '';
  if ($p->{title}) {
    $title = $p->{title};
  }
  elsif ($p->{h1}) {
    $title = $p->{h1};
  }

  if ($title eq '') {
    return '';
  }

  return WiKicker::UTF8::decode_from_unknown($title);
}

sub _get_title_for_wiki {
  my ($self, $content) = @_;

  my $title = $self->get_title_from_html($content);

  if (length($title) > 160) {
    return '';
  }

  return $self->normalize_title($title);
}

sub normalize_title {
  my ($self, $title) = @_;

  $title =~ s/\n/ /g;
  $title =~ s/^\s+//;
  $title =~ s/\s+$//;
  $title =~ s/\]+$//;
  
  return $title;
}  

sub get_bracketed_title {
  my ($self, $url) = @_;

  my $content = $self->get_content($url);
  return '' unless $content;
  my $title = $self->_get_title_for_wiki($content);
  return '' unless $title;

  return "[$title]";
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/Tool/GetUriTitle.pm <==
#
# WiKicker
#
#  GetUriTitle.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GetUriTitle.pm,v 1.6 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::Tool::GetUriTitle;

use strict;

use HTML::Parser;
use LWP::UserAgent;
use WiKicker::UTF8;

# my $tool = WiKicker::Tool::GetUriTitle->new;
# $tool->get_bracketed_title('http://www.google.com');

sub new {
  my $class = shift;

  return bless {}, $class;
}

sub start_handler {
  my ($self, $tagname) = @_;
  if ($tagname eq 'title') {
    $self->handler(text => sub { $self->{title} .= shift }, 'dtext');
    $self->handler(end  => sub { shift->eof if shift eq "title"; }, 'tagname,self');
  }
  elsif ($tagname eq 'h1') {
    $self->handler(text => sub { $self->{h1} .= shift }, 'dtext');
    $self->handler(end => sub { shift->eof if shift eq 'h1'; }, 'tagname, self');
  }
}

sub get_content {
  my ($self, $url) = @_;

  my $agent = LWP::UserAgent->new;
  my $response = $agent->request(HTTP::Request->new('GET', $url));
  unless ($response->is_success) {
    return '';
  }

  my $content_type = $response->content_type;
  if ($content_type && $content_type ne 'text/html') {
    return '';
  }
  unless ($content_type) {
    unless ($url =~ /\.html?$/) {
      return '';
    }
  }

  return $response->content;
}

sub get_title_from_html {
  my ($self, $html) = @_;

  my $p = HTML::Parser->new(api_version => 3);
  $p->handler(start => \&start_handler, 'self,tagname');
  $p->parse($html);
  my $title = '';
  if ($p->{title}) {
    $title = $p->{title};
  }
  elsif ($p->{h1}) {
    $title = $p->{h1};
  }

  if ($title eq '') {
    return '';
  }

  return WiKicker::UTF8::decode_from_unknown($title);
}

sub _get_title_for_wiki {
  my ($self, $content) = @_;

  my $title = $self->get_title_from_html($content);

  if (length($title) > 160) {
    return '';
  }

  return $self->normalize_title($title);
}

sub normalize_title {
  my ($self, $title) = @_;

  $title =~ s/\n/ /g;
  $title =~ s/^\s+//;
  $title =~ s/\s+$//;
  $title =~ s/\]+$//;

  return $title;
}

sub get_bracketed_title {
  my ($self, $url) = @_;

  my $content = $self->get_content($url);
  return '' unless $content;
  my $title = $self->_get_title_for_wiki($content);
  return '' unless $title;

  return "[$title]";
}

1;
